==> dde-network-core_2.0.58.tar.xz: BUILD/dss-network-plugin/translations/dss-network-plugin_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 mensaje nuevo</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Desactive primero el &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;modo avión&lt;/a&gt; si desea conectarse a una red inalámbrica</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>Conflicto de IP</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Red</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation>Conexión cableada %1</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Conexión PPPoE %1</translation>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>Conectando %1</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>&quot;%1&quot; conectado</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>&quot;%1&quot; desconectado</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>No se puede conectar &quot;%1&quot;, por favor, compruebe el router o el cable de red.</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>No se puede conectar &quot;%1&quot;, por favor manténgase cerca del enrutador inalámbrico</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>Fallo de conexión, no se puede conectar &quot;%1&quot;, contraseña incorrecta</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>Se requiere una contraseña para conectarse &quot;%1&quot;</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>No se puede encontrar la red WLAN 802.11 &quot;%1&quot; </translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>Para conectar &quot;%1&quot;, configure su información de autenticación después de iniciar sesión</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSecretWidget</name>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Contraseña privada</translation>
    </message>
    <message>
        <source>key</source>
        <translation>Clave</translation>
    </message>
    <message>
        <source>Proxy Password</source>
        <translation>Contraseña del proxy</translation>
    </message>
    <message>
        <source>Group Password</source>
        <translation>Contraseña del grupo</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nombre (SSID)</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Conectar</translation>
    </message>
</context>
<context>
    <name>dde::network::NetStatus</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Deshabilitar conexión cableada</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Activar conexión cableada</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Desactivar conexión inalámbrica</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Activar conexión inalámbrica</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Desactivar red</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Activar red</translation>
    </message>
    <message>
        <source>Disable VPN</source>
        <translation>Deshabilitar VPN</translation>
    </message>
    <message>
        <source>Enable VPN</source>
        <translation>Habilitar VPN</translation>
    </message>
    <message>
        <source>Disable system proxy</source>
        <translation>Deshabilitar el proxy del sistema</translation>
    </message>
    <message>
        <source>Enable system proxy</source>
        <translation>Habilitar el proxy del sistema</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Ajustes de red</translation>
    </message>
    <message>
        <source>Multiple services started</source>
        <translation>Múltiples servicios iniciados</translation>
    </message>
    <message>
        <source>Connected to: %1</source>
        <translation>Conectado a: %1</translation>
    </message>
    <message>
        <source>System proxy enabled</source>
        <translation>Proxy del sistema habilitado</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Conectado</translation>
    </message>
    <message>
        <source>Network off</source>
        <translation>Red apagada</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cable de red desconectado</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Sin conexión</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectado pero sin acceso a Internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>La conexión falló</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflicto de IP</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Red inalámbrica</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Conectado %1</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Apagado</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Red cableada</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Red</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy del sistema</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>La configuración de VPN no está conectada o falló al conectar. Por favor&lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;acceda a el centro de control&lt;/a&gt; para inspeccion.</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>Red cableada</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Red inalámbrica</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Conectarse a una red oculta</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>Mis Redes</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>Otras redes</translation>
    </message>
</context>
</TS>

==> dde-network-core_2.0.60.tar.xz: BUILD/dss-network-plugin/translations/dss-network-plugin_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 mensaje nuevo</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Si desea conectarse a una red inalámbrica, primero desactive el &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;modo avión&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>Conflicto de IP</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Red</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation>Conexión cableada %1</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Conexión PPPoE %1</translation>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>Conectando %1</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>&quot;%1&quot; conectado</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>&quot;%1&quot; desconectado</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>No se puede conectar &quot;%1&quot;, por favor, compruebe el router o el cable de red.</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>No se puede conectar &quot;%1&quot;, por favor manténgase cerca del enrutador inalámbrico</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>Fallo de conexión, no se puede conectar &quot;%1&quot;, contraseña incorrecta</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>Se requiere una contraseña para conectarse &quot;%1&quot;</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>No se puede encontrar la red WLAN 802.11 &quot;%1&quot; </translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>Para conectar &quot;%1&quot;, configure su información de autenticación después de iniciar sesión</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSecretWidget</name>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Contraseña privada</translation>
    </message>
    <message>
        <source>key</source>
        <translation>Clave</translation>
    </message>
    <message>
        <source>Proxy Password</source>
        <translation>Contraseña del proxy</translation>
    </message>
    <message>
        <source>Group Password</source>
        <translation>Contraseña del grupo</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nombre (SSID)</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Conectar</translation>
    </message>
</context>
<context>
    <name>dde::network::NetStatus</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Desactivar conexión cableada</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Activar conexión cableada</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Desactivar conexión inalámbrica</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Activar conexión inalámbrica</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Desactivar red</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Activar red</translation>
    </message>
    <message>
        <source>Disable VPN</source>
        <translation>Desactivar VPN</translation>
    </message>
    <message>
        <source>Enable VPN</source>
        <translation>Activar VPN</translation>
    </message>
    <message>
        <source>Disable system proxy</source>
        <translation>Desactivar el proxy del sistema</translation>
    </message>
    <message>
        <source>Enable system proxy</source>
        <translation>Activar el proxy del sistema</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Ajustes de red</translation>
    </message>
    <message>
        <source>Multiple services started</source>
        <translation>Múltiples servicios iniciados</translation>
    </message>
    <message>
        <source>Connected to: %1</source>
        <translation>Conectado a: %1</translation>
    </message>
    <message>
        <source>System proxy enabled</source>
        <translation>Proxy del sistema activado</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Conectado</translation>
    </message>
    <message>
        <source>Network off</source>
        <translation>Red apagada</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cable de red desconectado</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Sin conexión</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectado pero sin acceso a Internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>La conexión falló</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflicto de IP</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Red inalámbrica</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Conectado %1</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Apagado</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Red cableada</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Red</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy del sistema</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>La configuración de VPN no está conectada o falló al conectar. Por favor&lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;acceda a el centro de control&lt;/a&gt; para inspeccion.</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>Red cableada</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Red inalámbrica</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Conectarse a una red oculta</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>Mis Redes</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>Otras redes</translation>
    </message>
</context>
</TS>
